/**
 * Module Dependecies
 */

var Blog = require('../lib/blogjs'),
	assert = require('assert'),
	should = require('should'),
	fs = require('fs');
	
module.exports = {

	'test Blog.prototype._readIndex': function() {
		var	expected = fs.readFileSync(__dirname +	
			 '/fixtures/posts/post.idx', encoding='utf8'),
			blog = new Blog({
				root:'test/fixtures'
			});

		var raw = blog._readIndex();
		raw.should.be.a('string');
		raw.should.equal(expected);				
	},

	'test Blog.prototype._convert': function() {
		var	raw = fs.readFileSync(__dirname + 
			'/fixtures/posts/post.idx', encoding='utf8'),
			expected = [{
				"id": "post1",
				"title": "Title1",
				"path": "path/to/file1",
				"published": "true",
				"tags": "javascriptmvc,nodejs"
			},
			{
				"id": "post2",
				"title": "Title2",
				"path": "path/to/file2",
				"published": "true",
				"tags": "javascriptmvc,nodejs"
			}],
			blog = new Blog({
				root:'test',
				indexRelativePath: '/fixtures/post.idx'
			});

		var posts = blog._convert(raw);

		posts.should.be.an.instanceof(Array);
		posts.should.have.length(2);
		for(var i=0;i<2;i++) {
			var p = posts[i],
				e = expected[i];
			p.should.eql(e);
		}
	},

	'test Blog.prototype.findAll': function() {
		var blog = new Blog({
				root:'test/fixtures'
			}),
			expected = [{
				"id": "post1",
				"title": "Title1",
				"path": "path/to/file1",
				"published": "true",
				"tags": "javascriptmvc,nodejs"
			},
			{
				"id": "post2",
				"title": "Title2",
				"path": "path/to/file2",
				"published": "true",
				"tags": "javascriptmvc,nodejs"
			}];
	
		blog.findAll({}, function(err, posts) {
			posts.should.be.an.instanceof(Array);
			posts.should.have.length(2);
			for(var i=0;i<2;i++) {
				var p = posts[i],
					e = expected[i];
				p.should.eql(e);
			}
		});		
	},

	'test Blog.prototype.findPostSummaries': function() {
		var blog = new Blog({
				root:'test/fixtures'
			}),
			expected = [{
				"id": "post1",
				"title": "Title1",
				"summary": ""
			},
			{
				"id": "post2",
				"title": "Title2",
				"summary": ""
			}];
	
		blog.findPostSummaries({}, function(err, posts) {
			posts.should.be.an.instanceof(Array);
			posts.should.have.length(2);
			for(var i=0;i<2;i++) {
				var p = posts[i],
					e = expected[i];
				p.should.eql(e);
			}
		});		
	}
}
